<a id='changelog-0.1.1'></a>

# 0.1.1 — 2026-03-31

## Added

- Add `Cascader` hierarchical dropdown component supporting single-select and multi-select with cascading side-by-side panels. ([#1673](https://github.com/mckinsey/vizro/pull/1673/))

<a id='changelog-0.1.0'></a>

# 0.1.0 — 2026-03-06

## Added

- Initial release of vizro-dash-components (`vdc`) with `Markdown` component: a clone of `dcc.Markdown` that uses `dmc.CodeHighlight` and `dmc.InlineCodeHighlight`. ([#1571](https://github.com/mckinsey/vizro/pull/1571))
